@@ -10,11 +10,12 @@ import websocket
 import datetime
 from io import StringIO
 import json
+import os, ssl
 
 class client:
-    def __init__(self,base_url="http://35.184.152.222:9999"):
+    def __init__(self,api_key='',secret_key=''):
 
-        self.base_url = base_url
+        self.base_url = 'https://api.agrudtech.com';
 
     def validate_date(self,date_text):
         try:
@@ -33,6 +34,8 @@ class client:
             params["master_id"] = master_id
         if lookup:
             params["lookup"] = lookup
+        if (not os.environ.get('PYTHONHTTPSVERIFY', '') and getattr(ssl, '_create_unverified_context', None)):
+            ssl._create_default_https_context = ssl._create_unverified_context
         response = requests.get(security_url, params=params)
         try:
             if "[ERROR]" in response.text:
@@ -51,6 +54,8 @@ class client:
             params["indicator_category"] = indicator_category
         if lookup:
             params["lookup"] = lookup
+        if (not os.environ.get('PYTHONHTTPSVERIFY', '') and getattr(ssl, '_create_unverified_context', None)):
+            ssl._create_default_https_context = ssl._create_unverified_context
         response = requests.get(getallindicator_url, params=params)
         try:
             if "[ERROR]" in response.text:
@@ -65,6 +70,8 @@ class client:
             raise ValueError("Please provide valid user")
         params = {"user":user}
         portfolio_url = self.base_url + "/get_user_portfolio"
+        if (not os.environ.get('PYTHONHTTPSVERIFY', '') and getattr(ssl, '_create_unverified_context', None)):
+            ssl._create_default_https_context = ssl._create_unverified_context
         response = requests.get(portfolio_url, params=params)
         try:
             return response.json()
@@ -76,6 +83,8 @@ class client:
             raise ValueError("Please provide valid user/portfolio")
         params = {"user":user,"portfolio":portfolio}
         portfolio_url = self.base_url + "/get_portfolio_details"
+        if (not os.environ.get('PYTHONHTTPSVERIFY', '') and getattr(ssl, '_create_unverified_context', None)):
+            ssl._create_default_https_context = ssl._create_unverified_context
         response = requests.get(portfolio_url, params=params)
         try:
             return pd.DataFrame.from_dict(response.json()["portfolio_details"])
@@ -87,6 +96,8 @@ class client:
             raise ValueError("Please provide valid user/portfolio")
         params = {"user":user,"portfolio":portfolio,"indicators":indicators}
         portfolio_url = self.base_url + "/get_portfolio_data"
+        if (not os.environ.get('PYTHONHTTPSVERIFY', '') and getattr(ssl, '_create_unverified_context', None)):
+            ssl._create_default_https_context = ssl._create_unverified_context
         response = requests.get(portfolio_url, params=params)
         try:
             return pd.DataFrame.from_dict(response.json()["security_values"])
@@ -120,6 +131,8 @@ class client:
             params["master_id"] = master_id
         if indicator_id:
             params["indicator_id"] = indicator_id
+        if (not os.environ.get('PYTHONHTTPSVERIFY', '') and getattr(ssl, '_create_unverified_context', None)):
+            ssl._create_default_https_context = ssl._create_unverified_context
         main_request = requests.get(self.base_url + "/get_data",params=params)
         try:
             return pd.read_csv(StringIO(main_request.text))
